@@ -45,7 +45,7 @@ use Bio::MAGE::NameValueType;
 use vars qw(@ISA $VERSION @EXPORT_OK %EXPORT_TAGS $__MAGEML_LISTS $__MAGEML_PACKAGES $__CLASS2FULLCLASS);
 
 @ISA = qw(Bio::MAGE::Base Exporter);
-$VERSION = q[20020902.3];
+$VERSION = 20020902.6;
 
 use constant CARD_1 => '1';
 use constant CARD_0_OR_1 => '0..1';
@@ -153,7 +153,10 @@ This method returns a list of non-fully qualified class names
 =cut
 
 sub classes {
-  return ('Extendable', 'Identifiable', 'Describable', 'NameValueType');
+  return ('Extendable',
+'Identifiable',
+'Describable',
+'NameValueType');
 }
 
 =item $obj_ref = Bio::MAGE->new(%parameters)
@@ -207,138 +210,138 @@ sub mageml_packages {
 
 BEGIN {
   $__CLASS2FULLCLASS = {
-          'ReporterGroup' => 'Bio::MAGE::ArrayDesign::ReporterGroup',
-          'SeqFeatureLocation' => 'Bio::MAGE::BioSequence::SeqFeatureLocation',
-          'BibliographicReference' => 'Bio::MAGE::BQS::BibliographicReference',
-          'BioDataTuples' => 'Bio::MAGE::BioAssayData::BioDataTuples',
-          'ArrayGroup' => 'Bio::MAGE::Array::ArrayGroup',
-          'DistanceUnit' => 'Bio::MAGE::Measurement::DistanceUnit',
-          'ProtocolApplication' => 'Bio::MAGE::Protocol::ProtocolApplication',
-          'ManufactureLIMS' => 'Bio::MAGE::Array::ManufactureLIMS',
+          'Describable' => 'Bio::MAGE::Describable',
+          'Error' => 'Bio::MAGE::QuantitationType::Error',
+          'Parameter' => 'Bio::MAGE::Protocol::Parameter',
+          'ConfidenceIndicator' => 'Bio::MAGE::QuantitationType::ConfidenceIndicator',
+          'ImageAcquisition' => 'Bio::MAGE::BioAssay::ImageAcquisition',
+          'ArrayManufacture' => 'Bio::MAGE::Array::ArrayManufacture',
+          'Node' => 'Bio::MAGE::HigherLevelAnalysis::Node',
+          'Contact' => 'Bio::MAGE::AuditAndSecurity::Contact',
+          'Compound' => 'Bio::MAGE::BioMaterial::Compound',
+          'Protocol' => 'Bio::MAGE::Protocol::Protocol',
+          'DerivedSignal' => 'Bio::MAGE::QuantitationType::DerivedSignal',
+          'Array' => 'Bio::MAGE::Array::Array',
           'Hybridization' => 'Bio::MAGE::BioAssay::Hybridization',
-          'Security' => 'Bio::MAGE::AuditAndSecurity::Security',
-          'FeatureReporterMap' => 'Bio::MAGE::DesignElement::FeatureReporterMap',
-          'PositionDelta' => 'Bio::MAGE::Array::PositionDelta',
-          'DerivedBioAssayData' => 'Bio::MAGE::BioAssayData::DerivedBioAssayData',
-          'Hardware' => 'Bio::MAGE::Protocol::Hardware',
-          'CompositePosition' => 'Bio::MAGE::DesignElement::CompositePosition',
-          'ParameterValue' => 'Bio::MAGE::Protocol::ParameterValue',
-          'CompositeCompositeMap' => 'Bio::MAGE::DesignElement::CompositeCompositeMap',
-          'Audit' => 'Bio::MAGE::AuditAndSecurity::Audit',
+          'ConcentrationUnit' => 'Bio::MAGE::Measurement::ConcentrationUnit',
+          'QuantitationTypeDimension' => 'Bio::MAGE::BioAssayData::QuantitationTypeDimension',
+          'QuantitationType' => 'Bio::MAGE::QuantitationType::QuantitationType',
+          'BioSequence' => 'Bio::MAGE::BioSequence::BioSequence',
+          'BioEvent' => 'Bio::MAGE::BioEvent::BioEvent',
           'BioAssay' => 'Bio::MAGE::BioAssay::BioAssay',
-          'HardwareApplication' => 'Bio::MAGE::Protocol::HardwareApplication',
-          'Unit' => 'Bio::MAGE::Measurement::Unit',
+          'FactorValue' => 'Bio::MAGE::Experiment::FactorValue',
+          'MismatchInformation' => 'Bio::MAGE::DesignElement::MismatchInformation',
+          'Failed' => 'Bio::MAGE::QuantitationType::Failed',
+          'FeatureLocation' => 'Bio::MAGE::DesignElement::FeatureLocation',
+          'Hardware' => 'Bio::MAGE::Protocol::Hardware',
+          'PhysicalBioAssay' => 'Bio::MAGE::BioAssay::PhysicalBioAssay',
+          'CompositePosition' => 'Bio::MAGE::DesignElement::CompositePosition',
+          'DesignElementMapping' => 'Bio::MAGE::BioAssayData::DesignElementMapping',
+          'MeasuredBioAssayData' => 'Bio::MAGE::BioAssayData::MeasuredBioAssayData',
+          'ExperimentDesign' => 'Bio::MAGE::Experiment::ExperimentDesign',
+          'LabeledExtract' => 'Bio::MAGE::BioMaterial::LabeledExtract',
+          'DerivedBioAssay' => 'Bio::MAGE::BioAssay::DerivedBioAssay',
+          'Channel' => 'Bio::MAGE::BioAssay::Channel',
+          'FeatureExtraction' => 'Bio::MAGE::BioAssay::FeatureExtraction',
+          'PhysicalArrayDesign' => 'Bio::MAGE::ArrayDesign::PhysicalArrayDesign',
+          'BioSample' => 'Bio::MAGE::BioMaterial::BioSample',
+          'ParameterizableApplication' => 'Bio::MAGE::Protocol::ParameterizableApplication',
           'BioSource' => 'Bio::MAGE::BioMaterial::BioSource',
+          'ReporterCompositeMap' => 'Bio::MAGE::DesignElement::ReporterCompositeMap',
+          'Parameterizable' => 'Bio::MAGE::Protocol::Parameterizable',
+          'BioAssayData' => 'Bio::MAGE::BioAssayData::BioAssayData',
+          'StandardQuantitationType' => 'Bio::MAGE::QuantitationType::StandardQuantitationType',
+          'QuantityUnit' => 'Bio::MAGE::Measurement::QuantityUnit',
+          'BioDataCube' => 'Bio::MAGE::BioAssayData::BioDataCube',
+          'FeatureDimension' => 'Bio::MAGE::BioAssayData::FeatureDimension',
+          'Software' => 'Bio::MAGE::Protocol::Software',
+          'SoftwareApplication' => 'Bio::MAGE::Protocol::SoftwareApplication',
+          'Feature' => 'Bio::MAGE::DesignElement::Feature',
+          'MeasuredSignal' => 'Bio::MAGE::QuantitationType::MeasuredSignal',
+          'Description' => 'Bio::MAGE::Description::Description',
+          'DesignElement' => 'Bio::MAGE::DesignElement::DesignElement',
+          'SequencePosition' => 'Bio::MAGE::BioSequence::SequencePosition',
+          'Unit' => 'Bio::MAGE::Measurement::Unit',
+          'ParameterValue' => 'Bio::MAGE::Protocol::ParameterValue',
+          'Measurement' => 'Bio::MAGE::Measurement::Measurement',
+          'NodeValue' => 'Bio::MAGE::HigherLevelAnalysis::NodeValue',
+          'DistanceUnit' => 'Bio::MAGE::Measurement::DistanceUnit',
+          'MassUnit' => 'Bio::MAGE::Measurement::MassUnit',
+          'BioAssayDataCluster' => 'Bio::MAGE::HigherLevelAnalysis::BioAssayDataCluster',
+          'Extendable' => 'Bio::MAGE::Extendable',
+          'SpecializedQuantitationType' => 'Bio::MAGE::QuantitationType::SpecializedQuantitationType',
+          'Image' => 'Bio::MAGE::BioAssay::Image',
+          'ManufactureLIMSBiomaterial' => 'Bio::MAGE::Array::ManufactureLIMSBiomaterial',
+          'Ratio' => 'Bio::MAGE::QuantitationType::Ratio',
+          'CompoundMeasurement' => 'Bio::MAGE::BioMaterial::CompoundMeasurement',
+          'Person' => 'Bio::MAGE::AuditAndSecurity::Person',
+          'DesignElementGroup' => 'Bio::MAGE::ArrayDesign::DesignElementGroup',
+          'HardwareApplication' => 'Bio::MAGE::Protocol::HardwareApplication',
+          'BibliographicReference' => 'Bio::MAGE::BQS::BibliographicReference',
+          'ZoneLayout' => 'Bio::MAGE::ArrayDesign::ZoneLayout',
+          'DesignElementMap' => 'Bio::MAGE::BioAssayData::DesignElementMap',
+          'Database' => 'Bio::MAGE::Description::Database',
+          'BioAssayTreatment' => 'Bio::MAGE::BioAssay::BioAssayTreatment',
+          'ExternalReference' => 'Bio::MAGE::Description::ExternalReference',
+          'ExpectedValue' => 'Bio::MAGE::QuantitationType::ExpectedValue',
+          'ArrayGroup' => 'Bio::MAGE::Array::ArrayGroup',
+          'ExperimentalFactor' => 'Bio::MAGE::Experiment::ExperimentalFactor',
+          'BioMaterial' => 'Bio::MAGE::BioMaterial::BioMaterial',
+          'ReporterPosition' => 'Bio::MAGE::DesignElement::ReporterPosition',
+          'CompositeGroup' => 'Bio::MAGE::ArrayDesign::CompositeGroup',
+          'TemperatureUnit' => 'Bio::MAGE::Measurement::TemperatureUnit',
+          'NodeContents' => 'Bio::MAGE::HigherLevelAnalysis::NodeContents',
+          'OntologyEntry' => 'Bio::MAGE::Description::OntologyEntry',
+          'QuantitationTypeMap' => 'Bio::MAGE::BioAssayData::QuantitationTypeMap',
+          'Map' => 'Bio::MAGE::BioEvent::Map',
+          'Security' => 'Bio::MAGE::AuditAndSecurity::Security',
+          'SecurityGroup' => 'Bio::MAGE::AuditAndSecurity::SecurityGroup',
+          'Transformation' => 'Bio::MAGE::BioAssayData::Transformation',
+          'MeasuredBioAssay' => 'Bio::MAGE::BioAssay::MeasuredBioAssay',
+          'Experiment' => 'Bio::MAGE::Experiment::Experiment',
+          'SeqFeature' => 'Bio::MAGE::BioSequence::SeqFeature',
+          'TimeUnit' => 'Bio::MAGE::Measurement::TimeUnit',
+          'ReporterDimension' => 'Bio::MAGE::BioAssayData::ReporterDimension',
           'CompositeSequence' => 'Bio::MAGE::DesignElement::CompositeSequence',
           'PValue' => 'Bio::MAGE::QuantitationType::PValue',
-          'BioAssayDimension' => 'Bio::MAGE::BioAssayData::BioAssayDimension',
-          'StandardQuantitationType' => 'Bio::MAGE::QuantitationType::StandardQuantitationType',
-          'MismatchInformation' => 'Bio::MAGE::DesignElement::MismatchInformation',
-          'DesignElementDimension' => 'Bio::MAGE::BioAssayData::DesignElementDimension',
-          'Parameter' => 'Bio::MAGE::Protocol::Parameter',
-          'Feature' => 'Bio::MAGE::DesignElement::Feature',
-          'FeatureGroup' => 'Bio::MAGE::ArrayDesign::FeatureGroup',
-          'QuantitationType' => 'Bio::MAGE::QuantitationType::QuantitationType',
-          'ExternalReference' => 'Bio::MAGE::Description::ExternalReference',
-          'SequencePosition' => 'Bio::MAGE::BioSequence::SequencePosition',
-          'BioEvent' => 'Bio::MAGE::BioEvent::BioEvent',
-          'BioAssayDatum' => 'Bio::MAGE::BioAssayData::BioAssayDatum',
-          'MeasuredBioAssay' => 'Bio::MAGE::BioAssay::MeasuredBioAssay',
-          'CompositeGroup' => 'Bio::MAGE::ArrayDesign::CompositeGroup',
-          'BioAssayTreatment' => 'Bio::MAGE::BioAssay::BioAssayTreatment',
-          'Extendable' => 'Bio::MAGE::Extendable',
-          'SoftwareApplication' => 'Bio::MAGE::Protocol::SoftwareApplication',
-          'Node' => 'Bio::MAGE::HigherLevelAnalysis::Node',
-          'NodeValue' => 'Bio::MAGE::HigherLevelAnalysis::NodeValue',
-          'DerivedBioAssay' => 'Bio::MAGE::BioAssay::DerivedBioAssay',
-          'DatabaseEntry' => 'Bio::MAGE::Description::DatabaseEntry',
-          'Compound' => 'Bio::MAGE::BioMaterial::Compound',
-          'ArrayDesign' => 'Bio::MAGE::ArrayDesign::ArrayDesign',
-          'BioMaterialMeasurement' => 'Bio::MAGE::BioMaterial::BioMaterialMeasurement',
-          'Transformation' => 'Bio::MAGE::BioAssayData::Transformation',
-          'ConcentrationUnit' => 'Bio::MAGE::Measurement::ConcentrationUnit',
-          'BioMaterial' => 'Bio::MAGE::BioMaterial::BioMaterial',
-          'Treatment' => 'Bio::MAGE::BioMaterial::Treatment',
-          'BioAssayData' => 'Bio::MAGE::BioAssayData::BioAssayData',
-          'BioAssayCreation' => 'Bio::MAGE::BioAssay::BioAssayCreation',
-          'ReporterDimension' => 'Bio::MAGE::BioAssayData::ReporterDimension',
-          'ConfidenceIndicator' => 'Bio::MAGE::QuantitationType::ConfidenceIndicator',
-          'Failed' => 'Bio::MAGE::QuantitationType::Failed',
-          'ArrayManufactureDeviation' => 'Bio::MAGE::Array::ArrayManufactureDeviation',
-          'SpecializedQuantitationType' => 'Bio::MAGE::QuantitationType::SpecializedQuantitationType',
-          'FeatureInformation' => 'Bio::MAGE::DesignElement::FeatureInformation',
-          'ExperimentDesign' => 'Bio::MAGE::Experiment::ExperimentDesign',
-          'PhysicalArrayDesign' => 'Bio::MAGE::ArrayDesign::PhysicalArrayDesign',
-          'PhysicalBioAssay' => 'Bio::MAGE::BioAssay::PhysicalBioAssay',
-          'Ratio' => 'Bio::MAGE::QuantitationType::Ratio',
-          'FeatureLocation' => 'Bio::MAGE::DesignElement::FeatureLocation',
-          'DesignElement' => 'Bio::MAGE::DesignElement::DesignElement',
-          'QuantitationTypeDimension' => 'Bio::MAGE::BioAssayData::QuantitationTypeDimension',
-          'DerivedSignal' => 'Bio::MAGE::QuantitationType::DerivedSignal',
-          'Fiducial' => 'Bio::MAGE::Array::Fiducial',
-          'BioSequence' => 'Bio::MAGE::BioSequence::BioSequence',
-          'ReporterPosition' => 'Bio::MAGE::DesignElement::ReporterPosition',
-          'QuantitationTypeMapping' => 'Bio::MAGE::BioAssayData::QuantitationTypeMapping',
-          'MeasuredBioAssayData' => 'Bio::MAGE::BioAssayData::MeasuredBioAssayData',
-          'Identifiable' => 'Bio::MAGE::Identifiable',
-          'Position' => 'Bio::MAGE::DesignElement::Position',
-          'ExperimentalFactor' => 'Bio::MAGE::Experiment::ExperimentalFactor',
           'BioAssayMap' => 'Bio::MAGE::BioAssayData::BioAssayMap',
-          'Array' => 'Bio::MAGE::Array::Array',
-          'SeqFeature' => 'Bio::MAGE::BioSequence::SeqFeature',
-          'OntologyEntry' => 'Bio::MAGE::Description::OntologyEntry',
-          'ImageAcquisition' => 'Bio::MAGE::BioAssay::ImageAcquisition',
-          'FeatureExtraction' => 'Bio::MAGE::BioAssay::FeatureExtraction',
-          'Error' => 'Bio::MAGE::QuantitationType::Error',
-          'ArrayManufacture' => 'Bio::MAGE::Array::ArrayManufacture',
-          'Map' => 'Bio::MAGE::BioEvent::Map',
-          'Organization' => 'Bio::MAGE::AuditAndSecurity::Organization',
-          'Database' => 'Bio::MAGE::Description::Database',
-          'SecurityGroup' => 'Bio::MAGE::AuditAndSecurity::SecurityGroup',
-          'CompositeSequenceDimension' => 'Bio::MAGE::BioAssayData::CompositeSequenceDimension',
-          'Image' => 'Bio::MAGE::BioAssay::Image',
-          'Zone' => 'Bio::MAGE::ArrayDesign::Zone',
-          'NodeContents' => 'Bio::MAGE::HigherLevelAnalysis::NodeContents',
-          'Reporter' => 'Bio::MAGE::DesignElement::Reporter',
-          'FeatureDimension' => 'Bio::MAGE::BioAssayData::FeatureDimension',
-          'Protocol' => 'Bio::MAGE::Protocol::Protocol',
-          'Describable' => 'Bio::MAGE::Describable',
-          'ExpectedValue' => 'Bio::MAGE::QuantitationType::ExpectedValue',
-          'Contact' => 'Bio::MAGE::AuditAndSecurity::Contact',
-          'CompoundMeasurement' => 'Bio::MAGE::BioMaterial::CompoundMeasurement',
-          'MassUnit' => 'Bio::MAGE::Measurement::MassUnit',
-          'FactorValue' => 'Bio::MAGE::Experiment::FactorValue',
-          'ZoneDefect' => 'Bio::MAGE::Array::ZoneDefect',
-          'VolumeUnit' => 'Bio::MAGE::Measurement::VolumeUnit',
-          'DesignElementGroup' => 'Bio::MAGE::ArrayDesign::DesignElementGroup',
-          'ReporterCompositeMap' => 'Bio::MAGE::DesignElement::ReporterCompositeMap',
-          'LabeledExtract' => 'Bio::MAGE::BioMaterial::LabeledExtract',
-          'TimeUnit' => 'Bio::MAGE::Measurement::TimeUnit',
-          'FeatureDefect' => 'Bio::MAGE::Array::FeatureDefect',
-          'QuantityUnit' => 'Bio::MAGE::Measurement::QuantityUnit',
-          'BioAssayMapping' => 'Bio::MAGE::BioAssayData::BioAssayMapping',
-          'ZoneGroup' => 'Bio::MAGE::ArrayDesign::ZoneGroup',
-          'BioAssayDataCluster' => 'Bio::MAGE::HigherLevelAnalysis::BioAssayDataCluster',
-          'DesignElementMapping' => 'Bio::MAGE::BioAssayData::DesignElementMapping',
-          'Parameterizable' => 'Bio::MAGE::Protocol::Parameterizable',
-          'BioDataValues' => 'Bio::MAGE::BioAssayData::BioDataValues',
-          'DesignElementMap' => 'Bio::MAGE::BioAssayData::DesignElementMap',
-          'QuantitationTypeMap' => 'Bio::MAGE::BioAssayData::QuantitationTypeMap',
-          'Person' => 'Bio::MAGE::AuditAndSecurity::Person',
-          'ZoneLayout' => 'Bio::MAGE::ArrayDesign::ZoneLayout',
-          'ParameterizableApplication' => 'Bio::MAGE::Protocol::ParameterizableApplication',
-          'MeasuredSignal' => 'Bio::MAGE::QuantitationType::MeasuredSignal',
-          'Channel' => 'Bio::MAGE::BioAssay::Channel',
-          'BioDataCube' => 'Bio::MAGE::BioAssayData::BioDataCube',
-          'ManufactureLIMSBiomaterial' => 'Bio::MAGE::Array::ManufactureLIMSBiomaterial',
-          'BioSample' => 'Bio::MAGE::BioMaterial::BioSample',
           'NameValueType' => 'Bio::MAGE::NameValueType',
-          'TemperatureUnit' => 'Bio::MAGE::Measurement::TemperatureUnit',
+          'DesignElementDimension' => 'Bio::MAGE::BioAssayData::DesignElementDimension',
+          'FeatureReporterMap' => 'Bio::MAGE::DesignElement::FeatureReporterMap',
+          'ZoneDefect' => 'Bio::MAGE::Array::ZoneDefect',
+          'Zone' => 'Bio::MAGE::ArrayDesign::Zone',
+          'Organization' => 'Bio::MAGE::AuditAndSecurity::Organization',
+          'BioMaterialMeasurement' => 'Bio::MAGE::BioMaterial::BioMaterialMeasurement',
+          'FeatureInformation' => 'Bio::MAGE::DesignElement::FeatureInformation',
+          'BioDataValues' => 'Bio::MAGE::BioAssayData::BioDataValues',
+          'PositionDelta' => 'Bio::MAGE::Array::PositionDelta',
+          'BioAssayCreation' => 'Bio::MAGE::BioAssay::BioAssayCreation',
+          'QuantitationTypeMapping' => 'Bio::MAGE::BioAssayData::QuantitationTypeMapping',
+          'CompositeCompositeMap' => 'Bio::MAGE::DesignElement::CompositeCompositeMap',
+          'FeatureDefect' => 'Bio::MAGE::Array::FeatureDefect',
+          'Audit' => 'Bio::MAGE::AuditAndSecurity::Audit',
+          'BioAssayMapping' => 'Bio::MAGE::BioAssayData::BioAssayMapping',
+          'ArrayDesign' => 'Bio::MAGE::ArrayDesign::ArrayDesign',
+          'VolumeUnit' => 'Bio::MAGE::Measurement::VolumeUnit',
+          'Identifiable' => 'Bio::MAGE::Identifiable',
+          'ManufactureLIMS' => 'Bio::MAGE::Array::ManufactureLIMS',
+          'Position' => 'Bio::MAGE::DesignElement::Position',
+          'Fiducial' => 'Bio::MAGE::Array::Fiducial',
+          'Treatment' => 'Bio::MAGE::BioMaterial::Treatment',
+          'BioDataTuples' => 'Bio::MAGE::BioAssayData::BioDataTuples',
+          'ZoneGroup' => 'Bio::MAGE::ArrayDesign::ZoneGroup',
+          'DerivedBioAssayData' => 'Bio::MAGE::BioAssayData::DerivedBioAssayData',
+          'ProtocolApplication' => 'Bio::MAGE::Protocol::ProtocolApplication',
+          'CompositeSequenceDimension' => 'Bio::MAGE::BioAssayData::CompositeSequenceDimension',
+          'FeatureGroup' => 'Bio::MAGE::ArrayDesign::FeatureGroup',
+          'BioAssayDimension' => 'Bio::MAGE::BioAssayData::BioAssayDimension',
+          'BioAssayDatum' => 'Bio::MAGE::BioAssayData::BioAssayDatum',
+          'DatabaseEntry' => 'Bio::MAGE::Description::DatabaseEntry',
+          'ReporterGroup' => 'Bio::MAGE::ArrayDesign::ReporterGroup',
           'PresentAbsent' => 'Bio::MAGE::QuantitationType::PresentAbsent',
-          'Software' => 'Bio::MAGE::Protocol::Software',
-          'Experiment' => 'Bio::MAGE::Experiment::Experiment',
-          'Description' => 'Bio::MAGE::Description::Description',
-          'Measurement' => 'Bio::MAGE::Measurement::Measurement'
+          'Reporter' => 'Bio::MAGE::DesignElement::Reporter',
+          'SeqFeatureLocation' => 'Bio::MAGE::BioSequence::SeqFeatureLocation',
+          'ArrayManufactureDeviation' => 'Bio::MAGE::Array::ArrayManufactureDeviation'
         }
 ;
 }
