@@ -42,7 +42,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $__ASSOCIATIONS);
 require Exporter;
 
 @ISA = qw(Bio::MAGE::Base Bio::MAGE::AuditAndSecurity::Contact Exporter);
-$VERSION = q[$Id: Organization.pm,v 1.1 2002/12/10 06:25:48 jason_e_stewart Exp $];
+$VERSION = 20020902.6;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -111,72 +111,106 @@ named-value style arguments:
 
 =item * parent
 
-Sets the value of the parent association (from C<Bio::MAGE::AuditAndSecurity::Organization>).
+Sets the value of the parent association (this association was inherited
+from class C<Bio::MAGE::AuditAndSecurity::Organization>).
+
+The value will be of type C<Organization>.
 
 
 =item * URI
 
-Sets the value of the URI attribute (from C<Bio::MAGE::AuditAndSecurity::Contact>).
+Sets the value of the URI attribute (this attribute was inherited
+from class C<Bio::MAGE::AuditAndSecurity::Contact>).
+
 
 
 =item * address
 
-Sets the value of the address attribute (from C<Bio::MAGE::AuditAndSecurity::Contact>).
+Sets the value of the address attribute (this attribute was inherited
+from class C<Bio::MAGE::AuditAndSecurity::Contact>).
+
 
 
 =item * phone
 
-Sets the value of the phone attribute (from C<Bio::MAGE::AuditAndSecurity::Contact>).
+Sets the value of the phone attribute (this attribute was inherited
+from class C<Bio::MAGE::AuditAndSecurity::Contact>).
+
 
 
 =item * tollFreePhone
 
-Sets the value of the tollFreePhone attribute (from C<Bio::MAGE::AuditAndSecurity::Contact>).
+Sets the value of the tollFreePhone attribute (this attribute was inherited
+from class C<Bio::MAGE::AuditAndSecurity::Contact>).
+
 
 
 =item * email
 
-Sets the value of the email attribute (from C<Bio::MAGE::AuditAndSecurity::Contact>).
+Sets the value of the email attribute (this attribute was inherited
+from class C<Bio::MAGE::AuditAndSecurity::Contact>).
+
 
 
 =item * fax
 
-Sets the value of the fax attribute (from C<Bio::MAGE::AuditAndSecurity::Contact>).
+Sets the value of the fax attribute (this attribute was inherited
+from class C<Bio::MAGE::AuditAndSecurity::Contact>).
+
 
 
 =item * roles
 
-Sets the value of the roles association (from C<Bio::MAGE::AuditAndSecurity::Contact>).
+Sets the value of the roles association (this association was inherited
+from class C<Bio::MAGE::AuditAndSecurity::Contact>).
+
+The value will be of type C<OntologyEntry>.
 
 
 =item * identifier
 
-Sets the value of the identifier attribute (from C<Bio::MAGE::Identifiable>).
+Sets the value of the identifier attribute (this attribute was inherited
+from class C<Bio::MAGE::Identifiable>).
+
 
 
 =item * name
 
-Sets the value of the name attribute (from C<Bio::MAGE::Identifiable>).
+Sets the value of the name attribute (this attribute was inherited
+from class C<Bio::MAGE::Identifiable>).
 
 
-=item * security
-
-Sets the value of the security association (from C<Bio::MAGE::Describable>).
-
-
-=item * auditTrail
-
-Sets the value of the auditTrail association (from C<Bio::MAGE::Describable>).
-
 
 =item * descriptions
 
-Sets the value of the descriptions association (from C<Bio::MAGE::Describable>).
+Sets the value of the descriptions association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Description>.
+
+
+=item * security
+
+Sets the value of the security association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Security>.
+
+
+=item * auditTrail
+
+Sets the value of the auditTrail association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Audit>.
 
 
 =item * propertySets
 
-Sets the value of the propertySets association (from C<Bio::MAGE::Extendable>).
+Sets the value of the propertySets association (this association was inherited
+from class C<Bio::MAGE::Extendable>).
+
+The value will be of type C<NameValueType>.
 
 
 =back
@@ -745,24 +779,24 @@ BEGIN {
   $__ASSOCIATIONS = [
           'parent',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '0..N',
-                                        '__DOCUMENTATION' => 'The containing organization (the university or business which a lab belongs to, etc.)',
-                                        '__CLASS_NAME' => 'Organization',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'parent',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '1',
                                          '__CARDINALITY' => '0..1',
                                          '__DOCUMENTATION' => 'The containing organization (the university or business which a lab belongs to, etc.)',
-                                         '__CLASS_NAME' => 'Organization',
-                                         '__RANK' => '1',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'parent',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'Organization'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '0..N',
+                                        '__DOCUMENTATION' => 'The containing organization (the university or business which a lab belongs to, etc.)',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'Organization'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' )
         ]
 
