@@ -42,7 +42,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $__ASSOCIATIONS);
 require Exporter;
 
 @ISA = qw(Bio::MAGE::Base Bio::MAGE::BioAssay::BioAssay Exporter);
-$VERSION = q[$Id: DerivedBioAssay.pm,v 1.1 2002/12/10 06:25:48 jason_e_stewart Exp $];
+$VERSION = 20020902.6;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -61,19 +61,19 @@ $VERSION = q[$Id: DerivedBioAssay.pm,v 1.1 2002/12/10 06:25:48 jason_e_stewart E
 
     # creating an already populated instance
   my $derivedbioassay = Bio::MAGE::BioAssay::DerivedBioAssay->new(derivedBioAssayMap=>$derivedBioAssayMap_value,
-			type=>$type_value,
-			derivedBioAssayData=>$derivedBioAssayData_value);
+			derivedBioAssayData=>$derivedBioAssayData_value,
+			type=>$type_value);
 
     # setting and retrieving object associations
   my $derivedBioAssayMap_val = $derivedbioassay->derivedBioAssayMap();
   $derivedbioassay->derivedBioAssayMap($value);
 
-  my $type_val = $derivedbioassay->type();
-  $derivedbioassay->type($value);
-
   my $derivedBioAssayData_val = $derivedbioassay->derivedBioAssayData();
   $derivedbioassay->derivedBioAssayData($value);
 
+  my $type_val = $derivedbioassay->type();
+  $derivedbioassay->type($value);
+
 
 =head2 DESCRIPTION
 
@@ -119,57 +119,88 @@ named-value style arguments:
 
 =item * derivedBioAssayMap
 
-Sets the value of the derivedBioAssayMap association (from C<Bio::MAGE::BioAssay::DerivedBioAssay>).
+Sets the value of the derivedBioAssayMap association (this association was inherited
+from class C<Bio::MAGE::BioAssay::DerivedBioAssay>).
 
-
-=item * type
-
-Sets the value of the type association (from C<Bio::MAGE::BioAssay::DerivedBioAssay>).
+The value will be of type C<BioAssayMap>.
 
 
 =item * derivedBioAssayData
 
-Sets the value of the derivedBioAssayData association (from C<Bio::MAGE::BioAssay::DerivedBioAssay>).
+Sets the value of the derivedBioAssayData association (this association was inherited
+from class C<Bio::MAGE::BioAssay::DerivedBioAssay>).
+
+The value will be of type C<DerivedBioAssayData>.
 
 
-=item * channels
+=item * type
 
-Sets the value of the channels association (from C<Bio::MAGE::BioAssay::BioAssay>).
+Sets the value of the type association (this association was inherited
+from class C<Bio::MAGE::BioAssay::DerivedBioAssay>).
+
+The value will be of type C<OntologyEntry>.
 
 
 =item * bioAssayFactorValues
 
-Sets the value of the bioAssayFactorValues association (from C<Bio::MAGE::BioAssay::BioAssay>).
+Sets the value of the bioAssayFactorValues association (this association was inherited
+from class C<Bio::MAGE::BioAssay::BioAssay>).
+
+The value will be of type C<FactorValue>.
+
+
+=item * channels
+
+Sets the value of the channels association (this association was inherited
+from class C<Bio::MAGE::BioAssay::BioAssay>).
+
+The value will be of type C<Channel>.
 
 
 =item * identifier
 
-Sets the value of the identifier attribute (from C<Bio::MAGE::Identifiable>).
+Sets the value of the identifier attribute (this attribute was inherited
+from class C<Bio::MAGE::Identifiable>).
+
 
 
 =item * name
 
-Sets the value of the name attribute (from C<Bio::MAGE::Identifiable>).
+Sets the value of the name attribute (this attribute was inherited
+from class C<Bio::MAGE::Identifiable>).
 
 
-=item * security
-
-Sets the value of the security association (from C<Bio::MAGE::Describable>).
-
-
-=item * auditTrail
-
-Sets the value of the auditTrail association (from C<Bio::MAGE::Describable>).
-
 
 =item * descriptions
 
-Sets the value of the descriptions association (from C<Bio::MAGE::Describable>).
+Sets the value of the descriptions association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Description>.
+
+
+=item * security
+
+Sets the value of the security association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Security>.
+
+
+=item * auditTrail
+
+Sets the value of the auditTrail association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Audit>.
 
 
 =item * propertySets
 
-Sets the value of the propertySets association (from C<Bio::MAGE::Extendable>).
+Sets the value of the propertySets association (this association was inherited
+from class C<Bio::MAGE::Extendable>).
+
+The value will be of type C<NameValueType>.
 
 
 =back
@@ -332,7 +363,9 @@ returns the list of association accessor methods for this class.
 
 sub association_methods {
   my $class = shift;
-  my @list = ('derivedBioAssayMap', 'type', 'derivedBioAssayData');
+  my @list = ('derivedBioAssayMap',
+'derivedBioAssayData',
+'type');
   if ($class->superclasses()) {
     foreach ($class->superclasses()) {
       push(@list,$_->association_methods());
@@ -484,66 +517,66 @@ BEGIN {
   $__ASSOCIATIONS = [
           'type',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 0,
-                                        '__CARDINALITY' => '1',
-                                        '__DOCUMENTATION' => 'The derivation type, for instance collapsed spot replicate, ratio, averaged intensity, bioassay replicates, etc.',
-                                        '__CLASS_NAME' => 'DerivedBioAssay',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'type',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '1',
                                          '__CARDINALITY' => '0..1',
                                          '__DOCUMENTATION' => 'The derivation type, for instance collapsed spot replicate, ratio, averaged intensity, bioassay replicates, etc.',
-                                         '__CLASS_NAME' => 'OntologyEntry',
-                                         '__RANK' => '1',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'type',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'OntologyEntry'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 0,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '1',
+                                        '__DOCUMENTATION' => 'The derivation type, for instance collapsed spot replicate, ratio, averaged intensity, bioassay replicates, etc.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'DerivedBioAssay'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' ),
           'derivedBioAssayData',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '1..N',
-                                        '__DOCUMENTATION' => 'The data associated with the DerivedBioAssay.',
-                                        '__CLASS_NAME' => 'DerivedBioAssay',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'derivedBioAssayData',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '2',
                                          '__CARDINALITY' => '0..N',
                                          '__DOCUMENTATION' => 'The data associated with the DerivedBioAssay.',
-                                         '__CLASS_NAME' => 'DerivedBioAssayData',
-                                         '__RANK' => '2',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'derivedBioAssayData',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'DerivedBioAssayData'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '1..N',
+                                        '__DOCUMENTATION' => 'The data associated with the DerivedBioAssay.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'DerivedBioAssay'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' ),
           'derivedBioAssayMap',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => 'bioAssayMapTarget',
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '1',
-                                        '__DOCUMENTATION' => 'The DerivedBioAssay that is produced by the sources of the BioAssayMap.',
-                                        '__CLASS_NAME' => 'DerivedBioAssay',
-                                        '__RANK' => '1',
-                                        '__ORDERED' => 0
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'derivedBioAssayMap',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '3',
                                          '__CARDINALITY' => '0..N',
                                          '__DOCUMENTATION' => 'The DerivedBioAssay that is produced by the sources of the BioAssayMap.',
-                                         '__CLASS_NAME' => 'BioAssayMap',
-                                         '__RANK' => '3',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'derivedBioAssayMap',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'BioAssayMap'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => '1',
+                                        '__CARDINALITY' => '1',
+                                        '__DOCUMENTATION' => 'The DerivedBioAssay that is produced by the sources of the BioAssayMap.',
+                                        '__NAME' => 'bioAssayMapTarget',
+                                        '__ORDERED' => 0,
+                                        '__CLASS_NAME' => 'DerivedBioAssay'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' )
         ]
 
@@ -685,73 +718,6 @@ sub addDerivedBioAssayMap {
 
 
 
-=back
-
-
-=item type
-
-
-From the MAGE-OM documentation for the C<type> association:
-
-The derivation type, for instance collapsed spot replicate, ratio, averaged intensity, bioassay replicates, etc.
-
-
-
-=over
-
-
-=item $val = $derivedbioassay->setType($val)
-
-The restricted setter method for the type association.
-
-Input parameters: the value to which the type association will be set : an instance of type C<Bio::MAGE::Description::OntologyEntry>.
-
-Return value: the current value of the type association : an instance of type C<Bio::MAGE::Description::OntologyEntry>.
-
-Side effects: none
-
-Exceptions: will call C<croak()> if no input parameters are specified, or
-if too many input parameters are specified , or if $val is not an instance of class C<Bio::MAGE::Description::OntologyEntry>
-
-=cut
-
-sub setType {
-  my $self = shift;
-  croak(__PACKAGE__ . "::setType: no arguments passed to setter")
-    unless @_;
-  croak(__PACKAGE__ . "::setType: too many arguments passed to setter")
-    if @_ > 1;
-  my $val = shift;
-  croak(__PACKAGE__ . "::setType: wrong type: " . ref($val) . " expected Bio::MAGE::Description::OntologyEntry") unless UNIVERSAL::isa($val,'Bio::MAGE::Description::OntologyEntry');
-  return $self->{__TYPE} = $val;
-}
-
-
-
-=item $val = $derivedbioassay->getType()
-
-The restricted getter method for the type association.
-
-Input parameters: none
-
-Return value: the current value of the type association : an instance of type C<Bio::MAGE::Description::OntologyEntry>.
-
-Side effects: none
-
-Exceptions: will call C<croak()> if any input parameters are specified
-
-=cut
-
-sub getType {
-  my $self = shift;
-  croak(__PACKAGE__ . "::getType: arguments passed to getter")
-    if @_;
-  return $self->{__TYPE};
-}
-
-
-
-
 =back
 
 
@@ -857,6 +823,73 @@ sub addDerivedBioAssayData {
 
 
 
+=back
+
+
+=item type
+
+
+From the MAGE-OM documentation for the C<type> association:
+
+The derivation type, for instance collapsed spot replicate, ratio, averaged intensity, bioassay replicates, etc.
+
+
+
+=over
+
+
+=item $val = $derivedbioassay->setType($val)
+
+The restricted setter method for the type association.
+
+Input parameters: the value to which the type association will be set : an instance of type C<Bio::MAGE::Description::OntologyEntry>.
+
+Return value: the current value of the type association : an instance of type C<Bio::MAGE::Description::OntologyEntry>.
+
+Side effects: none
+
+Exceptions: will call C<croak()> if no input parameters are specified, or
+if too many input parameters are specified , or if $val is not an instance of class C<Bio::MAGE::Description::OntologyEntry>
+
+=cut
+
+sub setType {
+  my $self = shift;
+  croak(__PACKAGE__ . "::setType: no arguments passed to setter")
+    unless @_;
+  croak(__PACKAGE__ . "::setType: too many arguments passed to setter")
+    if @_ > 1;
+  my $val = shift;
+  croak(__PACKAGE__ . "::setType: wrong type: " . ref($val) . " expected Bio::MAGE::Description::OntologyEntry") unless UNIVERSAL::isa($val,'Bio::MAGE::Description::OntologyEntry');
+  return $self->{__TYPE} = $val;
+}
+
+
+
+=item $val = $derivedbioassay->getType()
+
+The restricted getter method for the type association.
+
+Input parameters: none
+
+Return value: the current value of the type association : an instance of type C<Bio::MAGE::Description::OntologyEntry>.
+
+Side effects: none
+
+Exceptions: will call C<croak()> if any input parameters are specified
+
+=cut
+
+sub getType {
+  my $self = shift;
+  croak(__PACKAGE__ . "::getType: arguments passed to getter")
+    if @_;
+  return $self->{__TYPE};
+}
+
+
+
+
 =back
 
 Associations Inherited from Bio::MAGE::BioAssay::BioAssay
