@@ -61,7 +61,7 @@ use Bio::MAGE::BioAssayData::FeatureDimension;
 use vars qw(@ISA $VERSION @EXPORT_OK %EXPORT_TAGS $__MAGEML_LISTS);
 
 @ISA = qw(Bio::MAGE::Base Exporter);
-$VERSION = q[$Id: BioAssayData.pm,v 1.1 2002/12/10 06:20:46 jason_e_stewart Exp $];
+$VERSION = 20020902.6;
 
 sub initialize {
   my $self = shift;
@@ -182,7 +182,26 @@ This method returns a list of non-fully qualified class names
 =cut
 
 sub classes {
-  return ('BioAssayData', 'QuantitationTypeDimension', 'BioAssayMapping', 'DesignElementDimension', 'BioAssayDatum', 'DerivedBioAssayData', 'MeasuredBioAssayData', 'QuantitationTypeMapping', 'DesignElementMapping', 'BioDataCube', 'BioDataValues', 'BioDataTuples', 'BioAssayDimension', 'QuantitationTypeMap', 'Transformation', 'DesignElementMap', 'BioAssayMap', 'CompositeSequenceDimension', 'ReporterDimension', 'FeatureDimension');
+  return ('BioAssayData',
+'QuantitationTypeDimension',
+'BioAssayMapping',
+'DesignElementDimension',
+'BioAssayDatum',
+'DerivedBioAssayData',
+'MeasuredBioAssayData',
+'QuantitationTypeMapping',
+'DesignElementMapping',
+'BioDataCube',
+'BioDataValues',
+'BioDataTuples',
+'BioAssayDimension',
+'QuantitationTypeMap',
+'Transformation',
+'DesignElementMap',
+'BioAssayMap',
+'CompositeSequenceDimension',
+'ReporterDimension',
+'FeatureDimension');
 }
 
 =item $obj_ref = Bio::MAGE::BioAssayData->new(%parameters)
