@@ -42,7 +42,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $__ASSOCIATIONS);
 require Exporter;
 
 @ISA = qw(Bio::MAGE::Base Bio::MAGE::BioAssayData::BioAssayData Exporter);
-$VERSION = q[$Id: DerivedBioAssayData.pm,v 1.1 2002/12/10 06:25:48 jason_e_stewart Exp $];
+$VERSION = 20020902.6;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -111,62 +111,96 @@ named-value style arguments:
 
 =item * producerTransformation
 
-Sets the value of the producerTransformation association (from C<Bio::MAGE::BioAssayData::DerivedBioAssayData>).
+Sets the value of the producerTransformation association (this association was inherited
+from class C<Bio::MAGE::BioAssayData::DerivedBioAssayData>).
 
-
-=item * bioAssayDimension
-
-Sets the value of the bioAssayDimension association (from C<Bio::MAGE::BioAssayData::BioAssayData>).
+The value will be of type C<Transformation>.
 
 
 =item * designElementDimension
 
-Sets the value of the designElementDimension association (from C<Bio::MAGE::BioAssayData::BioAssayData>).
+Sets the value of the designElementDimension association (this association was inherited
+from class C<Bio::MAGE::BioAssayData::BioAssayData>).
+
+The value will be of type C<DesignElementDimension>.
 
 
 =item * quantitationTypeDimension
 
-Sets the value of the quantitationTypeDimension association (from C<Bio::MAGE::BioAssayData::BioAssayData>).
+Sets the value of the quantitationTypeDimension association (this association was inherited
+from class C<Bio::MAGE::BioAssayData::BioAssayData>).
+
+The value will be of type C<QuantitationTypeDimension>.
+
+
+=item * bioAssayDimension
+
+Sets the value of the bioAssayDimension association (this association was inherited
+from class C<Bio::MAGE::BioAssayData::BioAssayData>).
+
+The value will be of type C<BioAssayDimension>.
 
 
 =item * summaryStatistics
 
-Sets the value of the summaryStatistics association (from C<Bio::MAGE::BioAssayData::BioAssayData>).
+Sets the value of the summaryStatistics association (this association was inherited
+from class C<Bio::MAGE::BioAssayData::BioAssayData>).
+
+The value will be of type C<NameValueType>.
 
 
 =item * bioDataValues
 
-Sets the value of the bioDataValues association (from C<Bio::MAGE::BioAssayData::BioAssayData>).
+Sets the value of the bioDataValues association (this association was inherited
+from class C<Bio::MAGE::BioAssayData::BioAssayData>).
+
+The value will be of type C<BioDataValues>.
 
 
 =item * identifier
 
-Sets the value of the identifier attribute (from C<Bio::MAGE::Identifiable>).
+Sets the value of the identifier attribute (this attribute was inherited
+from class C<Bio::MAGE::Identifiable>).
+
 
 
 =item * name
 
-Sets the value of the name attribute (from C<Bio::MAGE::Identifiable>).
+Sets the value of the name attribute (this attribute was inherited
+from class C<Bio::MAGE::Identifiable>).
 
 
-=item * security
-
-Sets the value of the security association (from C<Bio::MAGE::Describable>).
-
-
-=item * auditTrail
-
-Sets the value of the auditTrail association (from C<Bio::MAGE::Describable>).
-
 
 =item * descriptions
 
-Sets the value of the descriptions association (from C<Bio::MAGE::Describable>).
+Sets the value of the descriptions association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Description>.
+
+
+=item * security
+
+Sets the value of the security association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Security>.
+
+
+=item * auditTrail
+
+Sets the value of the auditTrail association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Audit>.
 
 
 =item * propertySets
 
-Sets the value of the propertySets association (from C<Bio::MAGE::Extendable>).
+Sets the value of the propertySets association (this association was inherited
+from class C<Bio::MAGE::Extendable>).
+
+The value will be of type C<NameValueType>.
 
 
 =back
@@ -481,24 +515,24 @@ BEGIN {
   $__ASSOCIATIONS = [
           'producerTransformation',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => 'derivedBioAssayDataTarget',
-                                        '__IS_REF' => 0,
-                                        '__CARDINALITY' => '1',
-                                        '__DOCUMENTATION' => 'The association between the DerivedBioAssayData and the Transformation event that produced it.',
-                                        '__CLASS_NAME' => 'DerivedBioAssayData',
-                                        '__RANK' => '2',
-                                        '__ORDERED' => 0
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'producerTransformation',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '1',
                                          '__CARDINALITY' => '0..1',
                                          '__DOCUMENTATION' => 'The association between the DerivedBioAssayData and the Transformation event that produced it.',
-                                         '__CLASS_NAME' => 'Transformation',
-                                         '__RANK' => '1',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'producerTransformation',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'Transformation'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 0,
+                                        '__RANK' => '2',
+                                        '__CARDINALITY' => '1',
+                                        '__DOCUMENTATION' => 'The association between the DerivedBioAssayData and the Transformation event that produced it.',
+                                        '__NAME' => 'derivedBioAssayDataTarget',
+                                        '__ORDERED' => 0,
+                                        '__CLASS_NAME' => 'DerivedBioAssayData'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' )
         ]
 
