@@ -42,7 +42,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $__ASSOCIATIONS);
 require Exporter;
 
 @ISA = qw(Bio::MAGE::Base Bio::MAGE::BioEvent::Map Exporter);
-$VERSION = q[$Id: QuantitationTypeMap.pm,v 1.1 2002/12/10 06:25:48 jason_e_stewart Exp $];
+$VERSION = 20020902.6;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -115,47 +115,72 @@ named-value style arguments:
 
 =item * sourcesQuantitationType
 
-Sets the value of the sourcesQuantitationType association (from C<Bio::MAGE::BioAssayData::QuantitationTypeMap>).
+Sets the value of the sourcesQuantitationType association (this association was inherited
+from class C<Bio::MAGE::BioAssayData::QuantitationTypeMap>).
+
+The value will be of type C<QuantitationType>.
 
 
 =item * targetQuantitationType
 
-Sets the value of the targetQuantitationType association (from C<Bio::MAGE::BioAssayData::QuantitationTypeMap>).
+Sets the value of the targetQuantitationType association (this association was inherited
+from class C<Bio::MAGE::BioAssayData::QuantitationTypeMap>).
+
+The value will be of type C<QuantitationType>.
 
 
 =item * protocolApplications
 
-Sets the value of the protocolApplications association (from C<Bio::MAGE::BioEvent::BioEvent>).
+Sets the value of the protocolApplications association (this association was inherited
+from class C<Bio::MAGE::BioEvent::BioEvent>).
+
+The value will be of type C<ProtocolApplication>.
 
 
 =item * identifier
 
-Sets the value of the identifier attribute (from C<Bio::MAGE::Identifiable>).
+Sets the value of the identifier attribute (this attribute was inherited
+from class C<Bio::MAGE::Identifiable>).
+
 
 
 =item * name
 
-Sets the value of the name attribute (from C<Bio::MAGE::Identifiable>).
+Sets the value of the name attribute (this attribute was inherited
+from class C<Bio::MAGE::Identifiable>).
 
 
-=item * security
-
-Sets the value of the security association (from C<Bio::MAGE::Describable>).
-
-
-=item * auditTrail
-
-Sets the value of the auditTrail association (from C<Bio::MAGE::Describable>).
-
 
 =item * descriptions
 
-Sets the value of the descriptions association (from C<Bio::MAGE::Describable>).
+Sets the value of the descriptions association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Description>.
+
+
+=item * security
+
+Sets the value of the security association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Security>.
+
+
+=item * auditTrail
+
+Sets the value of the auditTrail association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Audit>.
 
 
 =item * propertySets
 
-Sets the value of the propertySets association (from C<Bio::MAGE::Extendable>).
+Sets the value of the propertySets association (this association was inherited
+from class C<Bio::MAGE::Extendable>).
+
+The value will be of type C<NameValueType>.
 
 
 =back
@@ -318,7 +343,8 @@ returns the list of association accessor methods for this class.
 
 sub association_methods {
   my $class = shift;
-  my @list = ('sourcesQuantitationType', 'targetQuantitationType');
+  my @list = ('sourcesQuantitationType',
+'targetQuantitationType');
   if ($class->superclasses()) {
     foreach ($class->superclasses()) {
       push(@list,$_->association_methods());
@@ -470,45 +496,45 @@ BEGIN {
   $__ASSOCIATIONS = [
           'targetQuantitationType',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => 'quantitationTypeMaps',
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '0..N',
-                                        '__DOCUMENTATION' => 'The QuantitationType whose value will be produced from the values of the source QuantitationType according to the Protocol.',
-                                        '__CLASS_NAME' => 'QuantitationTypeMap',
-                                        '__RANK' => '5',
-                                        '__ORDERED' => 0
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'targetQuantitationType',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '1',
                                          '__CARDINALITY' => '1',
                                          '__DOCUMENTATION' => 'The QuantitationType whose value will be produced from the values of the source QuantitationType according to the Protocol.',
-                                         '__CLASS_NAME' => 'QuantitationType',
-                                         '__RANK' => '1',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'targetQuantitationType',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'QuantitationType'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => '5',
+                                        '__CARDINALITY' => '0..N',
+                                        '__DOCUMENTATION' => 'The QuantitationType whose value will be produced from the values of the source QuantitationType according to the Protocol.',
+                                        '__NAME' => 'quantitationTypeMaps',
+                                        '__ORDERED' => 0,
+                                        '__CLASS_NAME' => 'QuantitationTypeMap'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' ),
           'sourcesQuantitationType',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '0..N',
-                                        '__DOCUMENTATION' => 'The QuantitationType sources for values for the transformation.',
-                                        '__CLASS_NAME' => 'QuantitationTypeMap',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'sourcesQuantitationType',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '2',
                                          '__CARDINALITY' => '0..N',
                                          '__DOCUMENTATION' => 'The QuantitationType sources for values for the transformation.',
-                                         '__CLASS_NAME' => 'QuantitationType',
-                                         '__RANK' => '2',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'sourcesQuantitationType',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'QuantitationType'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '0..N',
+                                        '__DOCUMENTATION' => 'The QuantitationType sources for values for the transformation.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'QuantitationTypeMap'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' )
         ]
 
