@@ -42,7 +42,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $__ASSOCIATIONS);
 require Exporter;
 
 @ISA = qw(Bio::MAGE::Base Bio::MAGE::Extendable Exporter);
-$VERSION = q[$Id: SeqFeatureLocation.pm,v 1.1 2002/12/10 06:25:48 jason_e_stewart Exp $];
+$VERSION = 20020902.6;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -120,22 +120,33 @@ named-value style arguments:
 
 =item * strandType
 
-Sets the value of the strandType attribute (from C<Bio::MAGE::BioSequence::SeqFeatureLocation>).
+Sets the value of the strandType attribute (this attribute was inherited
+from class C<Bio::MAGE::BioSequence::SeqFeatureLocation>).
+
 
 
 =item * coordinate
 
-Sets the value of the coordinate association (from C<Bio::MAGE::BioSequence::SeqFeatureLocation>).
+Sets the value of the coordinate association (this association was inherited
+from class C<Bio::MAGE::BioSequence::SeqFeatureLocation>).
+
+The value will be of type C<SequencePosition>.
 
 
 =item * subregions
 
-Sets the value of the subregions association (from C<Bio::MAGE::BioSequence::SeqFeatureLocation>).
+Sets the value of the subregions association (this association was inherited
+from class C<Bio::MAGE::BioSequence::SeqFeatureLocation>).
+
+The value will be of type C<SeqFeatureLocation>.
 
 
 =item * propertySets
 
-Sets the value of the propertySets association (from C<Bio::MAGE::Extendable>).
+Sets the value of the propertySets association (this association was inherited
+from class C<Bio::MAGE::Extendable>).
+
+The value will be of type C<NameValueType>.
 
 
 =back
@@ -298,7 +309,8 @@ returns the list of association accessor methods for this class.
 
 sub association_methods {
   my $class = shift;
-  my @list = ('coordinate', 'subregions');
+  my @list = ('coordinate',
+'subregions');
   if ($class->superclasses()) {
     foreach ($class->superclasses()) {
       push(@list,$_->association_methods());
@@ -422,45 +434,45 @@ BEGIN {
   $__ASSOCIATIONS = [
           'subregions',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 0,
-                                        '__CARDINALITY' => '1',
-                                        '__DOCUMENTATION' => 'Regions within the SeqFeature.',
-                                        '__CLASS_NAME' => 'SeqFeatureLocation',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'subregions',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '1',
                                          '__CARDINALITY' => '0..N',
                                          '__DOCUMENTATION' => 'Regions within the SeqFeature.',
-                                         '__CLASS_NAME' => 'SeqFeatureLocation',
-                                         '__RANK' => '1',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'subregions',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'SeqFeatureLocation'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 0,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '1',
+                                        '__DOCUMENTATION' => 'Regions within the SeqFeature.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'SeqFeatureLocation'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' ),
           'coordinate',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 0,
-                                        '__CARDINALITY' => '1',
-                                        '__DOCUMENTATION' => 'At which base pairs or amino acid this SeqFeature begins and ends.',
-                                        '__CLASS_NAME' => 'SeqFeatureLocation',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'coordinate',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '2',
                                          '__CARDINALITY' => '1',
                                          '__DOCUMENTATION' => 'At which base pairs or amino acid this SeqFeature begins and ends.',
-                                         '__CLASS_NAME' => 'SequencePosition',
-                                         '__RANK' => '2',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'coordinate',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'SequencePosition'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 0,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '1',
+                                        '__DOCUMENTATION' => 'At which base pairs or amino acid this SeqFeature begins and ends.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'SeqFeatureLocation'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' )
         ]
 
