@@ -54,7 +54,7 @@ use Bio::MAGE::DesignElement::FeatureLocation;
 use vars qw(@ISA $VERSION @EXPORT_OK %EXPORT_TAGS $__MAGEML_LISTS);
 
 @ISA = qw(Bio::MAGE::Base Exporter);
-$VERSION = q[$Id: DesignElement.pm,v 1.1 2002/12/10 06:20:46 jason_e_stewart Exp $];
+$VERSION = 20020902.6;
 
 sub initialize {
   my $self = shift;
@@ -152,7 +152,19 @@ This method returns a list of non-fully qualified class names
 =cut
 
 sub classes {
-  return ('DesignElement', 'Position', 'Reporter', 'ReporterPosition', 'CompositePosition', 'CompositeSequence', 'Feature', 'MismatchInformation', 'FeatureInformation', 'CompositeCompositeMap', 'FeatureReporterMap', 'ReporterCompositeMap', 'FeatureLocation');
+  return ('DesignElement',
+'Position',
+'Reporter',
+'ReporterPosition',
+'CompositePosition',
+'CompositeSequence',
+'Feature',
+'MismatchInformation',
+'FeatureInformation',
+'CompositeCompositeMap',
+'FeatureReporterMap',
+'ReporterCompositeMap',
+'FeatureLocation');
 }
 
 =item $obj_ref = Bio::MAGE::DesignElement->new(%parameters)
