@@ -42,7 +42,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $__ASSOCIATIONS);
 require Exporter;
 
 @ISA = qw(Bio::MAGE::Base Bio::MAGE::Describable Exporter);
-$VERSION = q[$Id: NodeContents.pm,v 1.1 2002/12/10 06:25:49 jason_e_stewart Exp $];
+$VERSION = 20020902.6;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -60,17 +60,17 @@ $VERSION = q[$Id: NodeContents.pm,v 1.1 2002/12/10 06:25:49 jason_e_stewart Exp
   my $nodecontents = Bio::MAGE::HigherLevelAnalysis::NodeContents->new();
 
     # creating an already populated instance
-  my $nodecontents = Bio::MAGE::HigherLevelAnalysis::NodeContents->new(bioAssayDimension=>$bioAssayDimension_value,
-			designElementDimension=>$designElementDimension_value,
+  my $nodecontents = Bio::MAGE::HigherLevelAnalysis::NodeContents->new(designElementDimension=>$designElementDimension_value,
+			bioAssayDimension=>$bioAssayDimension_value,
 			quantitationDimension=>$quantitationDimension_value);
 
     # setting and retrieving object associations
-  my $bioAssayDimension_val = $nodecontents->bioAssayDimension();
-  $nodecontents->bioAssayDimension($value);
-
   my $designElementDimension_val = $nodecontents->designElementDimension();
   $nodecontents->designElementDimension($value);
 
+  my $bioAssayDimension_val = $nodecontents->bioAssayDimension();
+  $nodecontents->bioAssayDimension($value);
+
   my $quantitationDimension_val = $nodecontents->quantitationDimension();
   $nodecontents->quantitationDimension($value);
 
@@ -117,39 +117,60 @@ named-value style arguments:
 =over
 
 
-=item * bioAssayDimension
-
-Sets the value of the bioAssayDimension association (from C<Bio::MAGE::HigherLevelAnalysis::NodeContents>).
-
-
 =item * designElementDimension
 
-Sets the value of the designElementDimension association (from C<Bio::MAGE::HigherLevelAnalysis::NodeContents>).
+Sets the value of the designElementDimension association (this association was inherited
+from class C<Bio::MAGE::HigherLevelAnalysis::NodeContents>).
+
+The value will be of type C<DesignElementDimension>.
+
+
+=item * bioAssayDimension
+
+Sets the value of the bioAssayDimension association (this association was inherited
+from class C<Bio::MAGE::HigherLevelAnalysis::NodeContents>).
+
+The value will be of type C<BioAssayDimension>.
 
 
 =item * quantitationDimension
 
-Sets the value of the quantitationDimension association (from C<Bio::MAGE::HigherLevelAnalysis::NodeContents>).
+Sets the value of the quantitationDimension association (this association was inherited
+from class C<Bio::MAGE::HigherLevelAnalysis::NodeContents>).
 
-
-=item * security
-
-Sets the value of the security association (from C<Bio::MAGE::Describable>).
-
-
-=item * auditTrail
-
-Sets the value of the auditTrail association (from C<Bio::MAGE::Describable>).
+The value will be of type C<QuantitationTypeDimension>.
 
 
 =item * descriptions
 
-Sets the value of the descriptions association (from C<Bio::MAGE::Describable>).
+Sets the value of the descriptions association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Description>.
+
+
+=item * security
+
+Sets the value of the security association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Security>.
+
+
+=item * auditTrail
+
+Sets the value of the auditTrail association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Audit>.
 
 
 =item * propertySets
 
-Sets the value of the propertySets association (from C<Bio::MAGE::Extendable>).
+Sets the value of the propertySets association (this association was inherited
+from class C<Bio::MAGE::Extendable>).
+
+The value will be of type C<NameValueType>.
 
 
 =back
@@ -312,7 +333,9 @@ returns the list of association accessor methods for this class.
 
 sub association_methods {
   my $class = shift;
-  my @list = ('bioAssayDimension', 'designElementDimension', 'quantitationDimension');
+  my @list = ('designElementDimension',
+'bioAssayDimension',
+'quantitationDimension');
   if ($class->superclasses()) {
     foreach ($class->superclasses()) {
       push(@list,$_->association_methods());
@@ -370,66 +393,66 @@ BEGIN {
   $__ASSOCIATIONS = [
           'bioAssayDimension',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '1',
-                                        '__DOCUMENTATION' => 'The relevant BioAssays for this NodeContents from the BioAssayData.',
-                                        '__CLASS_NAME' => 'NodeContents',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'bioAssayDimension',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '1',
                                          '__CARDINALITY' => '0..1',
                                          '__DOCUMENTATION' => 'The relevant BioAssays for this NodeContents from the BioAssayData.',
-                                         '__CLASS_NAME' => 'BioAssayDimension',
-                                         '__RANK' => '1',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'bioAssayDimension',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'BioAssayDimension'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '1',
+                                        '__DOCUMENTATION' => 'The relevant BioAssays for this NodeContents from the BioAssayData.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'NodeContents'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' ),
           'designElementDimension',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '1',
-                                        '__DOCUMENTATION' => 'The relevant DesignElements for this NodeContents from the BioAssayData.',
-                                        '__CLASS_NAME' => 'NodeContents',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'designElementDimension',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '2',
                                          '__CARDINALITY' => '0..1',
                                          '__DOCUMENTATION' => 'The relevant DesignElements for this NodeContents from the BioAssayData.',
-                                         '__CLASS_NAME' => 'DesignElementDimension',
-                                         '__RANK' => '2',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'designElementDimension',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'DesignElementDimension'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '1',
+                                        '__DOCUMENTATION' => 'The relevant DesignElements for this NodeContents from the BioAssayData.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'NodeContents'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' ),
           'quantitationDimension',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '1',
-                                        '__DOCUMENTATION' => 'The relevant QuantitationTypes for this NodeContents from the BioAssayData.',
-                                        '__CLASS_NAME' => 'NodeContents',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'quantitationDimension',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '3',
                                          '__CARDINALITY' => '0..1',
                                          '__DOCUMENTATION' => 'The relevant QuantitationTypes for this NodeContents from the BioAssayData.',
-                                         '__CLASS_NAME' => 'QuantitationTypeDimension',
-                                         '__RANK' => '3',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'quantitationDimension',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'QuantitationTypeDimension'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '1',
+                                        '__DOCUMENTATION' => 'The relevant QuantitationTypes for this NodeContents from the BioAssayData.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'NodeContents'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' )
         ]
 
@@ -469,73 +492,6 @@ Bio::MAGE::HigherLevelAnalysis::NodeContents: has the following association acce
 =over
 
 
-=item bioAssayDimension
-
-
-From the MAGE-OM documentation for the C<bioAssayDimension> association:
-
-The relevant BioAssays for this NodeContents from the BioAssayData.
-
-
-
-=over
-
-
-=item $val = $nodecontents->setBioAssayDimension($val)
-
-The restricted setter method for the bioAssayDimension association.
-
-Input parameters: the value to which the bioAssayDimension association will be set : an instance of type C<Bio::MAGE::BioAssayData::BioAssayDimension>.
-
-Return value: the current value of the bioAssayDimension association : an instance of type C<Bio::MAGE::BioAssayData::BioAssayDimension>.
-
-Side effects: none
-
-Exceptions: will call C<croak()> if no input parameters are specified, or
-if too many input parameters are specified , or if $val is not an instance of class C<Bio::MAGE::BioAssayData::BioAssayDimension>
-
-=cut
-
-sub setBioAssayDimension {
-  my $self = shift;
-  croak(__PACKAGE__ . "::setBioAssayDimension: no arguments passed to setter")
-    unless @_;
-  croak(__PACKAGE__ . "::setBioAssayDimension: too many arguments passed to setter")
-    if @_ > 1;
-  my $val = shift;
-  croak(__PACKAGE__ . "::setBioAssayDimension: wrong type: " . ref($val) . " expected Bio::MAGE::BioAssayData::BioAssayDimension") unless UNIVERSAL::isa($val,'Bio::MAGE::BioAssayData::BioAssayDimension');
-  return $self->{__BIOASSAYDIMENSION} = $val;
-}
-
-
-
-=item $val = $nodecontents->getBioAssayDimension()
-
-The restricted getter method for the bioAssayDimension association.
-
-Input parameters: none
-
-Return value: the current value of the bioAssayDimension association : an instance of type C<Bio::MAGE::BioAssayData::BioAssayDimension>.
-
-Side effects: none
-
-Exceptions: will call C<croak()> if any input parameters are specified
-
-=cut
-
-sub getBioAssayDimension {
-  my $self = shift;
-  croak(__PACKAGE__ . "::getBioAssayDimension: arguments passed to getter")
-    if @_;
-  return $self->{__BIOASSAYDIMENSION};
-}
-
-
-
-
-=back
-
-
 =item designElementDimension
 
 
@@ -600,6 +556,73 @@ sub getDesignElementDimension {
 
 
 
+=back
+
+
+=item bioAssayDimension
+
+
+From the MAGE-OM documentation for the C<bioAssayDimension> association:
+
+The relevant BioAssays for this NodeContents from the BioAssayData.
+
+
+
+=over
+
+
+=item $val = $nodecontents->setBioAssayDimension($val)
+
+The restricted setter method for the bioAssayDimension association.
+
+Input parameters: the value to which the bioAssayDimension association will be set : an instance of type C<Bio::MAGE::BioAssayData::BioAssayDimension>.
+
+Return value: the current value of the bioAssayDimension association : an instance of type C<Bio::MAGE::BioAssayData::BioAssayDimension>.
+
+Side effects: none
+
+Exceptions: will call C<croak()> if no input parameters are specified, or
+if too many input parameters are specified , or if $val is not an instance of class C<Bio::MAGE::BioAssayData::BioAssayDimension>
+
+=cut
+
+sub setBioAssayDimension {
+  my $self = shift;
+  croak(__PACKAGE__ . "::setBioAssayDimension: no arguments passed to setter")
+    unless @_;
+  croak(__PACKAGE__ . "::setBioAssayDimension: too many arguments passed to setter")
+    if @_ > 1;
+  my $val = shift;
+  croak(__PACKAGE__ . "::setBioAssayDimension: wrong type: " . ref($val) . " expected Bio::MAGE::BioAssayData::BioAssayDimension") unless UNIVERSAL::isa($val,'Bio::MAGE::BioAssayData::BioAssayDimension');
+  return $self->{__BIOASSAYDIMENSION} = $val;
+}
+
+
+
+=item $val = $nodecontents->getBioAssayDimension()
+
+The restricted getter method for the bioAssayDimension association.
+
+Input parameters: none
+
+Return value: the current value of the bioAssayDimension association : an instance of type C<Bio::MAGE::BioAssayData::BioAssayDimension>.
+
+Side effects: none
+
+Exceptions: will call C<croak()> if any input parameters are specified
+
+=cut
+
+sub getBioAssayDimension {
+  my $self = shift;
+  croak(__PACKAGE__ . "::getBioAssayDimension: arguments passed to getter")
+    if @_;
+  return $self->{__BIOASSAYDIMENSION};
+}
+
+
+
+
 =back
 
 
