@@ -42,7 +42,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $__ASSOCIATIONS);
 require Exporter;
 
 @ISA = qw(Bio::MAGE::Base Bio::MAGE::Protocol::ParameterizableApplication Exporter);
-$VERSION = q[$Id: HardwareApplication.pm,v 1.1 2002/12/10 06:25:50 jason_e_stewart Exp $];
+$VERSION = 20020902.6;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -116,37 +116,57 @@ named-value style arguments:
 
 =item * serialNumber
 
-Sets the value of the serialNumber attribute (from C<Bio::MAGE::Protocol::HardwareApplication>).
+Sets the value of the serialNumber attribute (this attribute was inherited
+from class C<Bio::MAGE::Protocol::HardwareApplication>).
+
 
 
 =item * hardware
 
-Sets the value of the hardware association (from C<Bio::MAGE::Protocol::HardwareApplication>).
+Sets the value of the hardware association (this association was inherited
+from class C<Bio::MAGE::Protocol::HardwareApplication>).
+
+The value will be of type C<Hardware>.
 
 
 =item * parameterValues
 
-Sets the value of the parameterValues association (from C<Bio::MAGE::Protocol::ParameterizableApplication>).
+Sets the value of the parameterValues association (this association was inherited
+from class C<Bio::MAGE::Protocol::ParameterizableApplication>).
 
-
-=item * security
-
-Sets the value of the security association (from C<Bio::MAGE::Describable>).
-
-
-=item * auditTrail
-
-Sets the value of the auditTrail association (from C<Bio::MAGE::Describable>).
+The value will be of type C<ParameterValue>.
 
 
 =item * descriptions
 
-Sets the value of the descriptions association (from C<Bio::MAGE::Describable>).
+Sets the value of the descriptions association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Description>.
+
+
+=item * security
+
+Sets the value of the security association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Security>.
+
+
+=item * auditTrail
+
+Sets the value of the auditTrail association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Audit>.
 
 
 =item * propertySets
 
-Sets the value of the propertySets association (from C<Bio::MAGE::Extendable>).
+Sets the value of the propertySets association (this association was inherited
+from class C<Bio::MAGE::Extendable>).
+
+The value will be of type C<NameValueType>.
 
 
 =back
@@ -433,24 +453,24 @@ BEGIN {
   $__ASSOCIATIONS = [
           'hardware',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '0..N',
-                                        '__DOCUMENTATION' => 'The underlying hardware.',
-                                        '__CLASS_NAME' => 'HardwareApplication',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'hardware',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '1',
                                          '__CARDINALITY' => '1',
                                          '__DOCUMENTATION' => 'The underlying hardware.',
-                                         '__CLASS_NAME' => 'Hardware',
-                                         '__RANK' => '1',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'hardware',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'Hardware'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '0..N',
+                                        '__DOCUMENTATION' => 'The underlying hardware.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'HardwareApplication'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' )
         ]
 
