@@ -42,7 +42,7 @@ use vars qw($VERSION @ISA @EXPORT @EXPORT_OK $__ASSOCIATIONS);
 require Exporter;
 
 @ISA = qw(Bio::MAGE::Base Bio::MAGE::Protocol::Parameterizable Exporter);
-$VERSION = q[$Id: Software.pm,v 1.1 2002/12/10 06:25:50 jason_e_stewart Exp $];
+$VERSION = 20020902.6;
 
 # Items to export into callers namespace by default. Note: do not export
 # names by default without a very good reason. Use EXPORT_OK instead.
@@ -123,62 +123,95 @@ named-value style arguments:
 
 =item * softwareManufacturers
 
-Sets the value of the softwareManufacturers association (from C<Bio::MAGE::Protocol::Software>).
+Sets the value of the softwareManufacturers association (this association was inherited
+from class C<Bio::MAGE::Protocol::Software>).
+
+The value will be of type C<Contact>.
 
 
 =item * softwares
 
-Sets the value of the softwares association (from C<Bio::MAGE::Protocol::Software>).
+Sets the value of the softwares association (this association was inherited
+from class C<Bio::MAGE::Protocol::Software>).
+
+The value will be of type C<Software>.
 
 
 =item * hardware
 
-Sets the value of the hardware association (from C<Bio::MAGE::Protocol::Software>).
+Sets the value of the hardware association (this association was inherited
+from class C<Bio::MAGE::Protocol::Software>).
+
+The value will be of type C<Hardware>.
 
 
 =item * type
 
-Sets the value of the type association (from C<Bio::MAGE::Protocol::Software>).
+Sets the value of the type association (this association was inherited
+from class C<Bio::MAGE::Protocol::Software>).
+
+The value will be of type C<OntologyEntry>.
 
 
 =item * URI
 
-Sets the value of the URI attribute (from C<Bio::MAGE::Protocol::Parameterizable>).
+Sets the value of the URI attribute (this attribute was inherited
+from class C<Bio::MAGE::Protocol::Parameterizable>).
+
 
 
 =item * parameterTypes
 
-Sets the value of the parameterTypes association (from C<Bio::MAGE::Protocol::Parameterizable>).
+Sets the value of the parameterTypes association (this association was inherited
+from class C<Bio::MAGE::Protocol::Parameterizable>).
+
+The value will be of type C<Parameter>.
 
 
 =item * identifier
 
-Sets the value of the identifier attribute (from C<Bio::MAGE::Identifiable>).
+Sets the value of the identifier attribute (this attribute was inherited
+from class C<Bio::MAGE::Identifiable>).
+
 
 
 =item * name
 
-Sets the value of the name attribute (from C<Bio::MAGE::Identifiable>).
+Sets the value of the name attribute (this attribute was inherited
+from class C<Bio::MAGE::Identifiable>).
 
 
-=item * security
-
-Sets the value of the security association (from C<Bio::MAGE::Describable>).
-
-
-=item * auditTrail
-
-Sets the value of the auditTrail association (from C<Bio::MAGE::Describable>).
-
 
 =item * descriptions
 
-Sets the value of the descriptions association (from C<Bio::MAGE::Describable>).
+Sets the value of the descriptions association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Description>.
+
+
+=item * security
+
+Sets the value of the security association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Security>.
+
+
+=item * auditTrail
+
+Sets the value of the auditTrail association (this association was inherited
+from class C<Bio::MAGE::Describable>).
+
+The value will be of type C<Audit>.
 
 
 =item * propertySets
 
-Sets the value of the propertySets association (from C<Bio::MAGE::Extendable>).
+Sets the value of the propertySets association (this association was inherited
+from class C<Bio::MAGE::Extendable>).
+
+The value will be of type C<NameValueType>.
 
 
 =back
@@ -341,7 +374,10 @@ returns the list of association accessor methods for this class.
 
 sub association_methods {
   my $class = shift;
-  my @list = ('softwareManufacturers', 'softwares', 'hardware', 'type');
+  my @list = ('softwareManufacturers',
+'softwares',
+'hardware',
+'type');
   if ($class->superclasses()) {
     foreach ($class->superclasses()) {
       push(@list,$_->association_methods());
@@ -541,87 +577,87 @@ BEGIN {
   $__ASSOCIATIONS = [
           'type',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 0,
-                                        '__CARDINALITY' => '1',
-                                        '__DOCUMENTATION' => 'The type of a piece of Software.  Examples include: feature extractor...',
-                                        '__CLASS_NAME' => 'Software',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'type',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '1',
                                          '__CARDINALITY' => '0..1',
                                          '__DOCUMENTATION' => 'The type of a piece of Software.  Examples include: feature extractor...',
-                                         '__CLASS_NAME' => 'OntologyEntry',
-                                         '__RANK' => '1',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'type',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'OntologyEntry'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 0,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '1',
+                                        '__DOCUMENTATION' => 'The type of a piece of Software.  Examples include: feature extractor...',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'Software'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' ),
           'hardware',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => 'softwares',
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '0..N',
-                                        '__DOCUMENTATION' => 'Associates Hardware and Software together.',
-                                        '__CLASS_NAME' => 'Software',
-                                        '__RANK' => '2',
-                                        '__ORDERED' => 0
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'hardware',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '2',
                                          '__CARDINALITY' => '0..1',
                                          '__DOCUMENTATION' => 'Associates Hardware and Software together.',
-                                         '__CLASS_NAME' => 'Hardware',
-                                         '__RANK' => '2',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'hardware',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'Hardware'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => '2',
+                                        '__CARDINALITY' => '0..N',
+                                        '__DOCUMENTATION' => 'Associates Hardware and Software together.',
+                                        '__NAME' => 'softwares',
+                                        '__ORDERED' => 0,
+                                        '__CLASS_NAME' => 'Software'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' ),
           'softwares',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '0..N',
-                                        '__DOCUMENTATION' => 'Software packages this software uses, i.e. operating system, 3rd party software packages, etc.',
-                                        '__CLASS_NAME' => 'Software',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'softwares',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '3',
                                          '__CARDINALITY' => '0..N',
                                          '__DOCUMENTATION' => 'Software packages this software uses, i.e. operating system, 3rd party software packages, etc.',
-                                         '__CLASS_NAME' => 'Software',
-                                         '__RANK' => '3',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'softwares',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'Software'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '0..N',
+                                        '__DOCUMENTATION' => 'Software packages this software uses, i.e. operating system, 3rd party software packages, etc.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'Software'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' ),
           'softwareManufacturers',
           bless( {
-                   '__SELF' => bless( {
-                                        '__NAME' => undef,
-                                        '__IS_REF' => 1,
-                                        '__CARDINALITY' => '0..N',
-                                        '__DOCUMENTATION' => 'Contact for information on the software.',
-                                        '__CLASS_NAME' => 'Software',
-                                        '__RANK' => undef,
-                                        '__ORDERED' => undef
-                                      }, 'Bio::MAGE::Association::End' ),
                    '__OTHER' => bless( {
-                                         '__NAME' => 'softwareManufacturers',
                                          '__IS_REF' => 1,
+                                         '__RANK' => '4',
                                          '__CARDINALITY' => '0..N',
                                          '__DOCUMENTATION' => 'Contact for information on the software.',
-                                         '__CLASS_NAME' => 'Contact',
-                                         '__RANK' => '4',
-                                         '__ORDERED' => 0
-                                       }, 'Bio::MAGE::Association::End' )
+                                         '__NAME' => 'softwareManufacturers',
+                                         '__ORDERED' => 0,
+                                         '__CLASS_NAME' => 'Contact'
+                                       }, 'Bio::MAGE::Association::End' ),
+                   '__SELF' => bless( {
+                                        '__IS_REF' => 1,
+                                        '__RANK' => undef,
+                                        '__CARDINALITY' => '0..N',
+                                        '__DOCUMENTATION' => 'Contact for information on the software.',
+                                        '__NAME' => undef,
+                                        '__ORDERED' => undef,
+                                        '__CLASS_NAME' => 'Software'
+                                      }, 'Bio::MAGE::Association::End' )
                  }, 'Bio::MAGE::Association' )
         ]
 
